#define INTHREADING
#include <Threading.h>

int	CheckForThread(char *name)
{
int	t=0;

/* Find the next free threading DB no */
while ( t <= 4096 )
   {
   if ( ThreadDB[t].State == PT_RUNNING )
      {
      if ( strcmp(ThreadDB[t].Name,name) == 0 )
         {
         return 0;
         }
      }
   t++;
   }

return -1;
}
