#include <string.h>
#include <ctype.h>
#include <stdlib.h>

char *StringToupper( char *str )
{
char *strupout;
char toupret[3000];
int i=0;

while ( str[i] != 0 )
   {
   if (( str[i] > 96 ) && ( str[i] < 123 ))
      toupret[i] = toupper(str[i]);
   else
      toupret[i] = str[i];
   i++;
   if ( i > 1023 )
      break;
   }

toupret[i] = 0;

strupout = malloc(strlen(toupret)+1);
strcpy(strupout,toupret);

return strupout;
}
