#include <string.h>

char	RetFormedHit[1024];

char *SingleSpace( char *hit )
{
int	i=0,k=0,s=0;

/* Eliminates pre text spaces */
while( hit[i] == ' ' )
   i++;

while( hit[i] != 0 )
   {
   if (( hit[i] == ' ' ) || ( hit[i] == 0x09 ))
      {
      while (( hit[i] == ' ' ) || ( hit[i] == 0x09 ))
         i++;
      s++;
      RetFormedHit[k] = ' ';
//      RetFormedHit[k] = 0x09;
      k++;
      }
   RetFormedHit[k] = hit[i];
   k++;
   i++;
   }

RetFormedHit[k] = 0;
//Error(LOG_NOTICE,"String = %s",RetFormedHit);

return RetFormedHit;
}
