extern int TestFlag( char *flag, int argc, char *argv[] );
extern int CheckCMD( char *validflags, char *parmflags, int minstrings, int maxstrings, int argc, char *argv[] );
extern char *GetParmFlag( char *flag, int argc, char *argv[] );
