/* -TAG:LICENSE-
   
   This file is under the DigitalSpark Freeware Class License, see the
   file LICENSE for complete licensing information.
                                                         
                                                         -TAG:LICENSE- */
#include <Threading.h>
#include <Strings.h>
#include "tricky.h"

extern  size_t  Write( int slot, void *data, size_t size );

/* updates channel list, idstring, etc */

void	UpdateSessionInfo( int Block )
{
char	outbuff[1024];

//Error(9,"Update session request (%i)",Block);
sprintf(outbuff,"WHOIS %s\r\n",Nick);
Write(ServerSock,outbuff,0);
RefreshWhois = 0;
if ( Block == 1 )
   {
   while ( RefreshWhois == 0 )
      usleep(EnforcedWait);
   }
}
