#include <Threading.h>

/* 
   Do some basic things before the threads get started up and run.
*/

int Startup( void )
{
printf("------------( Threaded App %i.%i.%i\n",VerMajor,VerMinor,VerTiny);
Error(0,"Error Thread Running");
return 0;
}
