/* -TAG:LICENSE-
   
   This file is under the DigitalSpark Freeware Class License, see the
   file LICENSE for complete licensing information.
                                                         
                                                         -TAG:LICENSE- */
#include <Threading.h>
#include "tricky.h"

#define SA struct sockaddr

extern  char *NetGets( int sock, int end );
extern  size_t Write( int slot, void *data, size_t size );
extern	void	IRCServerMessage( int Sock, int number, char *message );
extern	void	IRCNotice( int Sock, char *type, char *message );

void SpoofServer( int Sock )
{
//char	outbuff[1024];

IRCNotice(Sock, "AUTH", "Resuming Session ...");
while ( Nick[0] == 0 )
   usleep(EnforcedWait);

IRCServerMessage(Sock,001,"Welcome to TrickyIRC");
IRCServerMessage(Sock,002,"Your host is a TrickyIRC Arbiter");
IRCNotice(Sock,Nick,"Your host is a TrickyIRC Arbiter");
IRCServerMessage(Sock,003,"This Arbiter was created by Trolld");
if ( ZeroZeroFour[0] != 0 )
   Write(Sock,ZeroZeroFour,0);
if ( ZeroZeroFive[0] != 0 )
   Write(Sock,ZeroZeroFive,0);

}
