#include <stdio.h>
#include <stdlib.h>
#include <string.h>

char SHRet[2048];

char *StripHeading(char *heading, char *string)
{
char buff[2048];
char head[2048];
int i=0;
int k=0;

strncpy(buff,string,2047);
strncpy(head,heading,2047);

while ( buff[i] == head[i] )
   i++;

while ( buff[i] != NULL )
   {
   SHRet[k] = buff[i];
   i++;
   k++;
   }   
SHRet[k] = buff[i];
      
return SHRet;
}
