/* -TAG:LICENSE-
   
   This file is under the DigitalSpark Freeware Class License, see the
   file LICENSE for complete licensing information.
                                                         
                                                         -TAG:LICENSE- */
#include <Threading.h>
#include "tricky.h"

extern  size_t Write( int slot, void *data, size_t size );

void IRCServerMessage( int Sock, int number, char *message )
{
char	buff[1024];

sprintf(buff,":%s %03i %s :%s\r\n",IRCServer, number, Nick, message);

Write(Sock,buff,0);
//Error(0,buff);

}
