#include <Threading.h>

extern int	ShutdownControl;
extern int	ThreadCount;
extern int	EnforcedWait;

struct ConfigArray{
	char keypath[1024];
        char keydata1[512];
        char keydata2[512];
        char keydata3[512];
        char keydata4[512];
        char keydata5[512];
	int count;
}ConfigDB[512];

extern int ConfigLoad(char *configfile);

void *ConfigManager( void )
{
char	report[1024];
/* Read in the config file */
if ( ConfigLoad(ConfigFilePath) == 0 )
   RegisterThread("ConfigMan","Manages the config setting DB",FALSE);
else
   {
   sprintf(report,"Config file [%s] couldn't be loaded.",ConfigFilePath);
   Error(4,report);
   }

while ( 1 )
{

sleep(10);
/* Sleep so thread isn't doing constant ifs */
}

}
